@@ -60,8 +60,6 @@ impl RpuDataMapping {
             data.mapping_idc[cmp].resize_with(pivot_idx_count, Default::default);
             data.num_mapping_param_predictors[cmp].resize_with(pivot_idx_count, Default::default);
             data.mapping_param_pred_flag[cmp].resize_with(pivot_idx_count, Default::default);
-            data.diff_pred_part_idx_mapping_minus1[cmp]
-                .resize_with(pivot_idx_count, Default::default);
 
             for pivot_idx in 0..pivot_idx_count {
                 data.mapping_idc[cmp][pivot_idx] = reader.get_ue()?;
@@ -81,13 +79,16 @@ impl RpuDataMapping {
                         if data.poly_order_minus1[cmp].is_empty() {
                             data.poly_order_minus1[cmp]
                                 .resize_with(pivot_idx_count, Default::default);
-                            data.linear_interp_flag[cmp]
-                                .resize_with(pivot_idx_count, Default::default);
                         }
 
                         data.poly_order_minus1[cmp][pivot_idx] = reader.get_ue()?;
 
                         if data.poly_order_minus1[cmp][pivot_idx] == 0 {
+                            if data.linear_interp_flag[cmp].is_empty() {
+                                data.linear_interp_flag[cmp]
+                                    .resize_with(pivot_idx_count, Default::default);
+                            }
+
                             data.linear_interp_flag[cmp][pivot_idx] = reader.get()?;
                         }
 
@@ -181,6 +182,11 @@ impl RpuDataMapping {
                         }
                     }
                 } else if data.num_mapping_param_predictors[cmp][pivot_idx] > 1 {
+                    if data.diff_pred_part_idx_mapping_minus1[cmp].is_empty() {
+                        data.diff_pred_part_idx_mapping_minus1[cmp]
+                            .resize_with(pivot_idx_count, Default::default);
+                    }
+
                     data.diff_pred_part_idx_mapping_minus1[cmp][pivot_idx] = reader.get_ue()?;
                 }
             }
@@ -313,133 +319,65 @@ impl RpuDataMapping {
     }
 
     pub fn p5_to_p81(&mut self) {
-        self.mapping_idc
-            .iter_mut()
-            .filter(|v| !v.is_empty())
-            .for_each(|v| {
-                v.truncate(1);
-                v[0] = 0;
-            });
+        self.mapping_idc.iter_mut().for_each(|v| {
+            v.clear();
+            v.push(0);
+        });
 
-        self.mapping_param_pred_flag
-            .iter_mut()
-            .filter(|v| !v.is_empty())
-            .for_each(|v| {
-                v.truncate(1);
-                v[0] = false;
-            });
+        self.mapping_param_pred_flag.iter_mut().for_each(|v| {
+            v.clear();
+            v.push(false);
+        });
 
-        self.num_mapping_param_predictors
-            .iter_mut()
-            .filter(|v| !v.is_empty())
-            .for_each(|v| {
-                v.truncate(1);
-                v[0] = 0;
-            });
+        self.num_mapping_param_predictors.iter_mut().for_each(|v| {
+            v.clear();
+            v.push(0);
+        });
 
         self.diff_pred_part_idx_mapping_minus1
             .iter_mut()
-            .filter(|v| !v.is_empty())
             .for_each(|v| {
-                v.truncate(1);
-                v[0] = 0;
+                v.clear();
+                v.push(0);
             });
 
-        self.poly_order_minus1
-            .iter_mut()
-            .filter(|v| !v.is_empty())
-            .for_each(|v| {
-                v.truncate(1);
-                v[0] = 0;
-            });
+        self.poly_order_minus1.iter_mut().for_each(|v| {
+            v.clear();
+            v.push(0);
+        });
 
-        self.linear_interp_flag
-            .iter_mut()
-            .filter(|v| !v.is_empty())
-            .for_each(|v| {
-                v.truncate(1);
-                v[0] = false;
-            });
+        self.linear_interp_flag.iter_mut().for_each(|v| {
+            v.clear();
+            v.push(false);
+        });
 
         self.pred_linear_interp_value_int
             .iter_mut()
-            .filter(|v| !v.is_empty())
-            .for_each(|v| {
-                v.truncate(1);
-                v[0] = 0;
-            });
+            .for_each(|v| v.clear());
 
         self.pred_linear_interp_value
             .iter_mut()
-            .filter(|v| !v.is_empty())
-            .for_each(|v| {
-                v.truncate(1);
-                v[0] = 0;
-            });
+            .for_each(|v| v.clear());
 
-        self.poly_coef_int
-            .iter_mut()
-            .filter(|v| !v.is_empty())
-            .for_each(|v| {
-                v.truncate(1);
-                v.iter_mut().filter(|v| !v.is_empty()).for_each(|v2| {
-                    v2.truncate(2);
-                    v2[0] = 0;
-                    v2[1] = 1;
-                });
-            });
+        self.poly_coef_int.iter_mut().for_each(|v| {
+            v.clear();
+            v.push(vec![0, 1]);
+        });
 
-        self.poly_coef
-            .iter_mut()
-            .filter(|v| !v.is_empty())
-            .for_each(|v| {
-                v.truncate(1);
-                v.iter_mut().filter(|v| !v.is_empty()).for_each(|v2| {
-                    v2.truncate(2);
-                    v2[0] = 0;
-                    v2[1] = 0;
-                });
-            });
+        self.poly_coef.iter_mut().for_each(|v| {
+            v.clear();
+            v.push(vec![0, 0]);
+        });
 
-        self.mmr_order_minus1
-            .iter_mut()
-            .filter(|v| !v.is_empty())
-            .for_each(|v| {
-                v.truncate(1);
-                v[0] = 0;
-            });
+        self.mmr_order_minus1.iter_mut().for_each(|v| v.clear());
 
-        self.mmr_constant_int
-            .iter_mut()
-            .filter(|v| !v.is_empty())
-            .for_each(|v| {
-                v.truncate(1);
-                v[0] = 0;
-            });
+        self.mmr_constant_int.iter_mut().for_each(|v| v.clear());
 
-        self.mmr_constant
-            .iter_mut()
-            .filter(|v| !v.is_empty())
-            .for_each(|v| {
-                v.truncate(1);
-                v[0] = 0;
-            });
+        self.mmr_constant.iter_mut().for_each(|v| v.clear());
 
-        self.mmr_coef_int
-            .iter_mut()
-            .filter(|v| !v.is_empty())
-            .for_each(|v| {
-                v.truncate(1);
-                v[0] = vec![];
-            });
+        self.mmr_coef_int.iter_mut().for_each(|v| v.clear());
 
-        self.mmr_coef
-            .iter_mut()
-            .filter(|v| !v.is_empty())
-            .for_each(|v| {
-                v.truncate(1);
-                v[0] = vec![];
-            });
+        self.mmr_coef.iter_mut().for_each(|v| v.clear());
     }
 
     pub fn p8_default() -> RpuDataMapping {
